# -*- coding: utf-8 -*-
"""
@Time: 2021/7/21 13:52
@Author: zzhang zzhang@cenboomh.com
@File: base_rule.py
@desc:
"""
from collect.collect_service import CollectService
from collect.service_imp.common.filters.template_tool import TemplateTool
from collect.utils.collect_utils import get_safe_data


class BaseRule(CollectService):
    def get_path_class_result(self, path, class_name, params, config_params, template):
        import importlib
        check_factory = importlib.import_module(path)
        check_obj = getattr(check_factory, class_name)(op_user=self.op_user)
        success, data, msg = check_obj.handler(params, config_params, template)
        if not success:
            return self.fail(msg)
        return self.success(data, msg=msg)

    def get_template_result(self, template_str, params, config_params, template):

        from collect.service_imp.common.filters.template_tool import TemplateTool
        template_tool = TemplateTool(op_user=self.op_user)
        value = template_tool.render(template_str, params, config_params, template)
        return self.success(value)

    def handler_node(self, key, node, params, config_params, template=None, check=False):
        """
        处理顺序，自定义方法> service> template
        处理模板规则节点
        :return:
        """
        # 自定义方法
        path = get_safe_data(self.get_path_name(), node)
        class_name = get_safe_data(self.get_class_name(), node)
        # 配置服务
        service = get_safe_data(self.get_service_name(), node)
        template_str = get_safe_data(self.get_template_name(), node)
        config_param = config_params[key]
        if path and class_name:
            # 自定义检查
            path_class_result = self.get_path_class_result(path, class_name, params, config_params, template)
            return path_class_result
        if service:
            template_tool = TemplateTool(op_user=self.op_user)
            for key in service:
                value_template = service[key]
                if value_template in params:
                    service[key] = params[value_template]
                else:
                    value = template_tool.render(value_template, params, config_params, template)
                    service[key] = value

            service_result = self.get_service_result(service, self.template)
            params[self.get_service_result_name()] = self.get_data(service_result)
            # 没有配置模板，或者结果是错误
            if not template_str or not self.is_success(service_result):
                return service_result

        if template_str:
            # 普通模板
            template_result = self.get_template_result(template_str, params, config_params, template)
            # if self.can_log(template):
            #     self.log(params)
            if self.is_success(template_result):
                template_result_data = self.get_data(template_result)

                if check and template_result_data == 'False':
                    err_msg = get_safe_data(self.get_err_msg_name(), node)
                    template_tool = TemplateTool(op_user=self.op_user)
                    msg = template_tool.render(err_msg, params, config_params, template)
                    return self.fail(msg)

            return template_result
